# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .components_schemas_composio_integration_exec_config import ComponentsSchemasComposioIntegrationExecConfig
from .integration_name import IntegrationName
from .integration_provider import IntegrationProvider


class IntegrationRead(UniversalBaseModel):
    id: str
    label: typing.Optional[str] = None
    icon_url: str
    name: IntegrationName
    provider: IntegrationProvider = "COMPOSIO"
    exec_config: ComponentsSchemasComposioIntegrationExecConfig = pydantic.Field()
    """
    Integration provider specific information needed for filtering tools.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
